package ru.vyatsu.qr_access_api.repository

import org.springframework.jdbc.core.JdbcTemplate
import org.springframework.stereotype.Repository
import ru.vyatsu.models.QrCode
import java.time.ZoneOffset
import java.util.*

private const val GET_QRS_BY_DOOR_IDS =
    "SELECT key_code, door_id, start_date_time, end_date_time FROM qrs WHERE door_id IN (?)"

@Repository
class QrRepository(private val template: JdbcTemplate) {

    fun getActualQrCodesByDoorIds(doorIds: Array<String>): List<QrCode> {
        return when {
            doorIds.isNotEmpty() -> template.query({ conn ->
                val doorIdsDbArray = conn.createArrayOf("TEXT", doorIds)
                val stmt = conn.prepareStatement(GET_QRS_BY_DOOR_IDS)
                stmt.setArray(1, doorIdsDbArray)
                stmt
            }, { rs, _ ->
                QrCode(
                    rs.getTimestamp("start_date_time").toLocalDateTime().atOffset(ZoneOffset.UTC),
                    rs.getTimestamp("end_date_time").toLocalDateTime().atOffset(ZoneOffset.UTC),
                    UUID.fromString(rs.getString("door_id")),
                    UUID.fromString(rs.getString("key_code"))
                )
            })

            else -> listOf()
        }
    }
}